@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,19 +17,97 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#if defined(WIN32)
-#if !defined(_WIN32_WINNT) && defined(WINVER)
-#define _WIN32_WINNT WINVER
-#elif !defined(_WIN32_WINNT)
-#define _WIN32_WINNT 0x0403
-#endif
-#endif
-
-#include <osipparser2/osip_port.h>
-
 #ifndef _INTERNAL_H_
 #define _INTERNAL_H_
 
+#if defined (HAVE_CONFIG_H)
+#include <osip-config.h>
+#endif
+
+#if defined(__PALMOS__) && (__PALMOS__ >= 0x06000000)
+#	define HAVE_CTYPE_H 1
+#	define HAVE_STRING_H 1
+#	define HAVE_SYS_TYPES_H 1
+#	define HAVE_TIME_H 1
+#	define HAVE_STDARG_H 1
+
+#elif defined(__VXWORKS_OS__) || defined(__rtems__)
+#define HAVE_STRING_H 1
+#define HAVE_TIME_H 1
+#define HAVE_SYS_TIME_H 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_STDARG_H 1
+
+#elif defined _WIN32_WCE
+
+#define HAVE_CTYPE_H 1
+#define HAVE_STRING_H 1
+#define HAVE_TIME_H 1
+#define HAVE_STDARG_H 1
+
+#define snprintf  _snprintf
+
+#elif defined(WIN32)
+
+#define HAVE_CTYPE_H 1
+#define HAVE_STRING_H 1
+#define HAVE_SYS_TYPES_H 1
+#define HAVE_TIME_H 1
+#define HAVE_STDARG_H 1
+
+#define snprintf _snprintf
+
+/* use win32 crypto routines for random number generation */
+/* only use for vs .net (compiler v. 1300) or greater */
+#if _MSC_VER >= 1300
+#define WIN32_USE_CRYPTO 1
+#endif
+
+#endif
+
+#if defined (HAVE_STRING_H)
+#include <string.h>
+#elif defined (HAVE_STRINGS_H)
+#include <strings.h>
+#else
+#include <string.h>
+#endif
+
+#include <stdio.h>
+#include <stdlib.h>
+
+#if defined (HAVE_SYS_TYPES_H)
+#include <sys/types.h>
+#endif
+
+#ifdef HAVE_TIME_H
+#include <time.h>
+#endif
+
+#if defined (HAVE_SYS_TIME_H)
+#include <sys/time.h>
+#endif
+
+#if defined(__arc__)
+#include "includes_api.h"
+#include "os_cfg_pub.h"
+#include <posix_time_pub.h>
+#endif
+
+#ifdef __PSOS__
+#define VA_START(a, f)  va_start(a, f)
+#include "pna.h"
+#include "stdlib.h"
+#include "time.h"
+#define timercmp(tvp, uvp, cmp) \
+((tvp)->tv_sec cmp (uvp)->tv_sec || \
+(tvp)->tv_sec == (uvp)->tv_sec && (tvp)->tv_usec cmp (uvp)->tv_usec)
+#define snprintf  osip_snprintf
+#ifndef INT_MAX
+#define INT_MAX 0x7FFFFFFF
+#endif
+#endif
+
 #ifdef __BORLANDC__
 #define _timeb timeb
 #define _ftime ftime
@@ -40,47 +118,12 @@
 #if !( defined(__rtems__) || defined(__PALMOS__) || defined(HAVE_STRUCT_TIMEVAL) )
 /* Struct timeval */
 struct timeval {
-	long tv_sec;				/* seconds */
-	long tv_usec;				/* and microseconds */
+  long tv_sec;                  /* seconds */
+  long tv_usec;                 /* and microseconds */
 };
 #endif
 
-/**
- * Structure for payload management. Each payload element
- * represents one codec of a media line.
- * @var __payload_t
- */
-typedef struct __payload __payload_t;
-
-struct __payload {
-	char *payload;
-	/*  char *port; this must be assigned by the application dynamicly */
-	char *number_of_port;
-	char *proto;
-	char *c_nettype;
-	char *c_addrtype;
-	char *c_addr;
-	char *c_addr_multicast_ttl;
-	char *c_addr_multicast_int;
-	/* rtpmap (rcvonly and other attributes are added dynamicly) */
-	char *a_rtpmap;
-};
-
-
-/**
- * Allocate a payload element.
- * @param payload The payload.
- */
-int __payload_init(__payload_t ** payload);
-
-/**
- * Free a payload element.
- * @param payload The payload.
- */
-void __payload_free(__payload_t * payload);
-
-
-#ifdef OSIP_MT
+#ifndef OSIP_MONOTHREAD
 
 /* Thread abstraction layer definition */
 #if defined(__rtems__)
@@ -118,22 +161,22 @@ typedef pthread_t osip_thread_t;
 #undef _WINSOCKAPI_
 
 typedef struct {
-	HANDLE h;
-	unsigned id;
+  HANDLE h;
+  unsigned id;
 } osip_thread_t;
 #endif
 
 #ifdef __VXWORKS_OS__
 #include <taskLib.h>
 typedef struct {
-	int id;
+  int id;
 } osip_thread_t;
 #endif
 
 #ifdef __PSOS__
 #include <psos.h>
 typedef struct {
-	unsigned long tid;
+  unsigned long tid;
 } osip_thread_t;
 #endif
 
@@ -162,8 +205,8 @@ typedef pthread_mutex_t osip_mutex_t;
 #if defined(__arc__)
 
 typedef struct {
-	int _sem_counter;
-	struct osip_mutex *_sem_mutex;
+  int _sem_counter;
+  struct osip_mutex *_sem_mutex;
 } sem_t;
 
 typedef sem_t osip_sem_t;
@@ -185,14 +228,14 @@ typedef sem_t osip_sem_t;
 #include <mach/semaphore.h>
 #include <mach/mach_init.h>
 typedef struct {
-	semaphore_t semid;
+  semaphore_t semid;
 } osip_sem_t;
 #elif defined(HAVE_SYS_SEM_H)
 #include <sys/types.h>
 #include <sys/ipc.h>
 #include <sys/sem.h>
 typedef struct {
-	int semid;
+  int semid;
 } osip_sem_t;
 #endif
 
@@ -207,17 +250,17 @@ typedef struct {
 
 #define OSIP_CRITICALSECTION_SPIN  4000
 typedef struct {
-	CRITICAL_SECTION h;
+  CRITICAL_SECTION h;
 } osip_mutex_t;
 #else
 
 typedef struct {
-	HANDLE h;
+  HANDLE h;
 } osip_mutex_t;
 #endif
 
 typedef struct {
-	HANDLE h;
+  HANDLE h;
 } osip_sem_t;
 #endif
 
@@ -232,10 +275,10 @@ typedef sem_t osip_sem_t;
 #include <Types.h>
 #include <os.h>
 typedef struct {
-	UInt32 id;
+  UInt32 id;
 } osip_mutex_t;
 typedef struct {
-	UInt32 id;
+  UInt32 id;
 } osip_sem_t;
 #endif
 
@@ -248,20 +291,20 @@ typedef struct {
  */
 #if defined(HAVE_PTHREAD) || defined(HAVE_PTH_PTHREAD_H) || defined(HAVE_PTHREAD_WIN32)
 typedef struct osip_cond {
-	pthread_cond_t cv;
+  pthread_cond_t cv;
 } osip_cond_t;
 #endif
 
 #if (defined(WIN32) || defined(_WIN32_WCE)) && !defined(HAVE_PTHREAD_WIN32)
 typedef struct osip_cond {
-	struct osip_mutex *mut;
-	struct osip_sem *sem;
+  struct osip_mutex *mut;
+  struct osip_sem *sem;
 } osip_cond_t;
 #endif
 
 #if defined(__PSOS__) || defined(__VXWORKS_OS__)
 typedef struct osip_cond {
-	struct osip_sem *sem;
+  struct osip_sem *sem;
 } osip_cond_t;
 #endif
 
@@ -269,21 +312,21 @@ typedef struct osip_cond {
 
 #if defined(__rtems__)
 typedef struct {
-	rtems_id tid;
+  rtems_id tid;
 } osip_thread_t;
 
 typedef struct {
-	rtems_id id;
+  rtems_id id;
 } osip_sem_t;
 
 typedef struct {
-	rtems_id id;
+  rtems_id id;
 } osip_mutex_t;
 #endif
 
 
-#endif							/* #ifdef OSIP_MT */
+#endif /* #ifndef OSIP_MONOTHREAD */
 
-#endif							/* #ifndef DOXYGEN */
+#endif /* #ifndef DOXYGEN */
 
-#endif							/* #ifndef _INTERNAL_H_ */
+#endif /* #ifndef _INTERNAL_H_ */
