@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -55,7 +55,7 @@ extern "C"
  * Free an Accept element.
  * @param header The element to work on.
  */
-#define osip_accept_free(header)     osip_content_type_free(header)
+#define osip_accept_free     osip_content_type_free
 /**
  * Parse an Accept element.
  * @param header The element to work on.
