@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -36,14 +36,18 @@
 
 /**
  * Structure for Call-Info headers.
- * @defvar osip_call_info_t
+ * @var osip_call_info_t
  */
   typedef struct osip_call_info osip_call_info_t;
 
+/**
+ * Definition of the Call-Info header.
+ * @struct osip_call_info
+ */
   struct osip_call_info
   {
-    char *element;
-    osip_list_t *gen_params;
+    char *element;              /**< Call-Info main value */
+    osip_list_t gen_params;     /**< Parameters for Call-Info header */
   };
 
 #ifdef __cplusplus
