@@ -1,6 +1,6 @@
 /*
-  The oSIP library implements the Session Initiation Protocol (SIP -rfc2543-)
-  Copyright (C) 2001  Aymeric MOIZARD jack@atosc.org
+  The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -35,21 +35,25 @@
 
 /**
  * Structure for WWW-Authenticate headers.
- * @defvar osip_www_authenticate_t
+ * @var osip_www_authenticate_t
  */
   typedef struct osip_www_authenticate osip_www_authenticate_t;
 
+/**
+ * Definition of the WWW-Authenticate header.
+ * @struct osip_www_authenticate
+ */
   struct osip_www_authenticate
   {
-    char *auth_type;		/* ( "Basic" | "Digest" )      */
-    char *realm;		/* mandatory ( quoted-string ) */
-    char *domain;		/* optional  <"> 1#URI <">     */
-    char *nonce;		/* mandatory */
-    char *opaque;		/* optional  */
-    char *stale;		/* optional  ( "true" | "false" ) */
-    char *algorithm;		/* optional  ( "MD5"  | token   ) */
-    char *qop_options;		/* optional  */
-    char *auth_param;		/* optional  */
+    char *auth_type;		/**< Authentication Type (Basic or Digest */
+    char *realm;		/**< realm (as a quoted-string) */
+    char *domain;		/**< domain (optional) */
+    char *nonce;		/**< nonce (optional)*/
+    char *opaque;		/**< opaque (optional) */
+    char *stale;		/**< stale (optional) */
+    char *algorithm;		/**< algorythm (optional) */
+    char *qop_options;		/**< qop option (optional)  */
+    char *auth_param;		/**< other parameters (optional) */
   };
 
 
