@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -39,8 +39,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -53,64 +52,63 @@ extern "C"
  * Structure for SIP Message (REQUEST and RESPONSE).
  * @struct osip_message
  */
-  struct osip_message
-  {
-    char *sip_version;                /**< SIP version (SIP request only) */
-    osip_uri_t *req_uri;              /**< Request-Uri (SIP request only) */
-    char *sip_method;                 /**< METHOD (SIP request only) */
+  struct osip_message {
+    char *sip_version;                            /**< SIP version (SIP request only) */
+    osip_uri_t *req_uri;                          /**< Request-Uri (SIP request only) */
+    char *sip_method;                             /**< METHOD (SIP request only) */
 
-    int status_code;                  /**< Status Code (SIP answer only) */
-    char *reason_phrase;              /**< Reason Phrase (SIP answer only) */
+    int status_code;                              /**< Status Code (SIP answer only) */
+    char *reason_phrase;                          /**< Reason Phrase (SIP answer only) */
 
 #ifndef MINISIZE
-    osip_list_t accepts;             /**< Accept headers */
-    osip_list_t accept_encodings;    /**< Accept-Encoding headers */
-    osip_list_t accept_languages;    /**< Accept-Language headers */
-    osip_list_t alert_infos;         /**< Alert-Info headers */
-    osip_list_t allows;              /**< Allows headers */
-    osip_list_t authentication_infos;/**< authentication_info headers */
+    osip_list_t accepts;                          /**< Accept headers */
+    osip_list_t accept_encodings;                 /**< Accept-Encoding headers */
+    osip_list_t accept_languages;                 /**< Accept-Language headers */
+    osip_list_t alert_infos;                      /**< Alert-Info headers */
+    osip_list_t allows;                           /**< Allows headers */
+    osip_list_t authentication_infos;             /**< authentication_info headers */
 #endif
-    osip_list_t authorizations;      /**< Authorizations headers */
-    osip_call_id_t *call_id;          /**< Call-ID header */
+    osip_list_t authorizations;                   /**< Authorizations headers */
+    osip_call_id_t *call_id;                      /**< Call-ID header */
 #ifndef MINISIZE
-    osip_list_t call_infos;          /**< Call-Infos header */
+    osip_list_t call_infos;                       /**< Call-Infos header */
 #endif
-    osip_list_t contacts;            /**< Contacts headers */
+    osip_list_t contacts;                         /**< Contacts headers */
 #ifndef MINISIZE
-    osip_list_t content_encodings;   /**< Content-Encodings headers */
+    osip_list_t content_encodings;                /**< Content-Encodings headers */
 #endif
-    osip_content_length_t *content_length;   /**< Content-Length header */
-    osip_content_type_t *content_type;       /**< Content-Type header */
-    osip_cseq_t *cseq;                /**< CSeq header */
+    osip_content_length_t *content_length;        /**< Content-Length header */
+    osip_content_type_t *content_type;            /**< Content-Type header */
+    osip_cseq_t *cseq;                            /**< CSeq header */
 #ifndef MINISIZE
-    osip_list_t error_infos;         /**< Error-Info headers */
+    osip_list_t error_infos;                      /**< Error-Info headers */
 #endif
-    osip_from_t *from;                /**< From header */
-    osip_mime_version_t *mime_version;/**< Mime-Version header */
-    osip_list_t proxy_authenticates; /**< Proxy-Authenticate headers */
+    osip_from_t *from;                            /**< From header */
+    osip_mime_version_t *mime_version;            /**< Mime-Version header */
+    osip_list_t proxy_authenticates;              /**< Proxy-Authenticate headers */
 #ifndef MINISIZE
-    osip_list_t proxy_authentication_infos; /**< P-Authentication-Info headers */
+    osip_list_t proxy_authentication_infos;       /**< P-Authentication-Info headers */
 #endif
-    osip_list_t proxy_authorizations;/**< Proxy-authorization headers */
-    osip_list_t record_routes;       /**< Record-Route headers */
-    osip_list_t routes;              /**< Route headers */
-    osip_to_t *to;                    /**< To header */
-    osip_list_t vias;                /**< Vias headers */
-    osip_list_t www_authenticates;   /**< WWW-Authenticate headers */
+    osip_list_t proxy_authorizations;             /**< Proxy-authorization headers */
+    osip_list_t record_routes;                    /**< Record-Route headers */
+    osip_list_t routes;                           /**< Route headers */
+    osip_to_t *to;                                /**< To header */
+    osip_list_t vias;                             /**< Vias headers */
+    osip_list_t www_authenticates;                /**< WWW-Authenticate headers */
 
-    osip_list_t headers;             /**< Other headers */
+    osip_list_t headers;                          /**< Other headers */
 
-    osip_list_t bodies;              /**< List of attachements */
+    osip_list_t bodies;                           /**< List of attachements */
 
     /*
        1: structure and buffer "message" are identical.
        2: buffer "message" is not up to date with the structure info (call osip_message_to_str to update it).
      */
-    int message_property;             /**@internal */
-    char *message;                    /**@internal */
-    size_t message_length;            /**@internal */
+    int message_property;                         /**< internal value */
+    char *message;                                /**< internal value */
+    size_t message_length;                        /**< internal value */
 
-    void *application_data;           /**can be used by upper layer*/
+    void *application_data;                       /**< can be used by upper layer*/
   };
 
 #ifndef SIP_MESSAGE_MAX_LENGTH
@@ -150,16 +148,14 @@ extern "C"
  * @param buf The buffer to parse.
  * @param length The length of the buffer to parse.
  */
-  int osip_message_parse_sipfrag (osip_message_t * sip, const char *buf,
-                                  size_t length);
+  int osip_message_parse_sipfrag (osip_message_t * sip, const char *buf, size_t length);
 /**
  * Get a string representation of a osip_message_t element.
  * @param sip The element to work on.
  * @param dest new allocated buffer returned.
  * @param message_length The length of the returned buffer.
  */
-  int osip_message_to_str (osip_message_t * sip, char **dest,
-                           size_t * message_length);
+  int osip_message_to_str (osip_message_t * sip, char **dest, size_t * message_length);
 /**
  * Get a string representation of a message/sipfrag part
  * stored in an osip_message_t element.
@@ -167,8 +163,7 @@ extern "C"
  * @param dest new allocated buffer returned.
  * @param message_length The length of the returned buffer.
  */
-  int osip_message_to_str_sipfrag (osip_message_t * sip, char **dest,
-                                   size_t * message_length);
+  int osip_message_to_str_sipfrag (osip_message_t * sip, char **dest, size_t * message_length);
 /**
  * Clone a osip_message_t element.
  * @param sip The element to clone.
@@ -439,8 +434,7 @@ extern "C"
  * @param generic_param The element to work on.
  * @param name the token name to set.
  */
-  void osip_generic_param_set_name (osip_generic_param_t * generic_param,
-                                    char *name);
+  void osip_generic_param_set_name (osip_generic_param_t * generic_param, char *name);
 /**
  * Get the name of a generic parameter element.
  * @param generic_param The element to work on.
@@ -451,8 +445,7 @@ extern "C"
  * @param generic_param The element to work on.
  * @param value the token name to set.
  */
-  void osip_generic_param_set_value (osip_generic_param_t * generic_param,
-                                     char *value);
+  void osip_generic_param_set_value (osip_generic_param_t * generic_param, char *value);
 /**
  * Get the value of a generic parameter element.
  * @param generic_param The element to work on.
@@ -466,9 +459,7 @@ extern "C"
  * @param pos The index of the element to get.
  * @param dest A pointer on the header found.
  */
-  int osip_message_get_knownheaderlist (osip_list_t *header_list,
-					int pos,
-					void **dest);
+  int osip_message_get_knownheaderlist (osip_list_t * header_list, int pos, void **dest);
 
 /** @} */
 
@@ -476,5 +467,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif
