@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -39,8 +39,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 /**
@@ -53,10 +52,10 @@ extern "C"
  * Structure for referencing url parameters.
  * @struct osip_uri_param
  */
-  struct osip_uri_param
-  {
-    char *gname;    /**< uri parameter name */
-    char *gvalue;   /**< uri parameter value */
+  struct osip_uri_param {
+    char *gname;            /**< uri parameter name */
+    char *gvalue;
+                                        /**< uri parameter value */
   };
 
 /**
@@ -87,8 +86,7 @@ extern "C"
  * @param url_param The element to work on.
  * @param dest The resulting new allocated element.
  */
-  int osip_uri_param_clone (const osip_uri_param_t * url_param,
-                            osip_uri_param_t ** dest);
+  int osip_uri_param_clone (const osip_uri_param_t * url_param, osip_uri_param_t ** dest);
 #ifndef DOXYGEN
 /*
  * Free a list of a url parameter element.
@@ -109,8 +107,7 @@ extern "C"
  * @param name The name of the parameter element to find.
  * @param dest A pointer on the element found.
  */
-  int osip_uri_param_get_byname (osip_list_t * url_params, char *name,
-                                 osip_uri_param_t ** dest);
+  int osip_uri_param_get_byname (osip_list_t * url_params, char *name, osip_uri_param_t ** dest);
 
 /**
  * Allocate a generic parameter element.
@@ -167,17 +164,18 @@ extern "C"
  * Structure for referencing SIP urls.
  * @struct osip_uri
  */
-  struct osip_uri
-  {
-    char *scheme;              /**< Uri Scheme (sip or sips) */
-    char *username;            /**< Username */
-    char *password;            /**< Password */
-    char *host;                /**< Domain */
-    char *port;                /**< Port number */
-    osip_list_t url_params;    /**< Uri parameters */
-    osip_list_t url_headers;   /**< Uri headers */
+  struct osip_uri {
+    char *scheme;                          /**< Uri Scheme (sip or sips) */
+    char *username;                        /**< Username */
+    char *password;                        /**< Password */
+    char *host;                                    /**< Domain */
+    char *port;                                    /**< Port number */
+    osip_list_t url_params;            /**< Uri parameters */
+    osip_list_t url_headers;
+                                                           /**< Uri headers */
 
-    char *string;  /**< Space for other url schemes. (http, mailto...) */
+    char *string;
+                                   /**< Space for other url schemes. (http, mailto...) */
   };
 
 /**
@@ -406,11 +404,9 @@ extern "C"
 
 #ifndef DOXYGEN
 /* internal method */
-  char *next_separator (const char *ch, int separator_osip_to_find,
-                        int before_separator);
+  char *next_separator (const char *ch, int separator_osip_to_find, int before_separator);
 
-  char *__osip_uri_escape_nonascii_and_nondef (const char *string,
-                                               const char *def);
+  char *__osip_uri_escape_nonascii_and_nondef (const char *string, const char *def);
   char *__osip_uri_escape_userinfo (const char *string);
   char *__osip_uri_escape_password (const char *string);
   char *__osip_uri_escape_uri_param (char *string);
@@ -424,5 +420,4 @@ extern "C"
 #ifdef __cplusplus
 }
 #endif
-
 #endif                          /*  _URLS_H_ */
