@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -17,8 +17,7 @@
   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 */
 
-#include <stdlib.h>
-#include <stdio.h>
+#include <osipparser2/internal.h>
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
@@ -29,34 +28,36 @@
 /* INPUT : const char *hvalue | value of header.    */
 /* OUTPUT: osip_message_t *sip | structure to save results.  */
 /* returns -1 on error. */
-int osip_message_set_mime_version(osip_message_t * sip, const char *hvalue)
+int
+osip_message_set_mime_version (osip_message_t * sip, const char *hvalue)
 {
-	int i;
+  int i;
 
-	if (hvalue == NULL || hvalue[0] == '\0')
-		return OSIP_SUCCESS;
+  if (hvalue == NULL || hvalue[0] == '\0')
+    return OSIP_SUCCESS;
 
-	if (sip->mime_version != NULL)
-		return OSIP_SYNTAXERROR;
-	i = osip_mime_version_init(&(sip->mime_version));
-	if (i != 0)
-		return i;
-	sip->message_property = 2;
-	i = osip_mime_version_parse(sip->mime_version, hvalue);
-	if (i != 0) {
-		osip_mime_version_free(sip->mime_version);
-		sip->mime_version = NULL;
-		return i;
-	}
-	return OSIP_SUCCESS;
+  if (sip->mime_version != NULL)
+    return OSIP_SYNTAXERROR;
+  i = osip_mime_version_init (&(sip->mime_version));
+  if (i != 0)
+    return i;
+  sip->message_property = 2;
+  i = osip_mime_version_parse (sip->mime_version, hvalue);
+  if (i != 0) {
+    osip_mime_version_free (sip->mime_version);
+    sip->mime_version = NULL;
+    return i;
+  }
+  return OSIP_SUCCESS;
 }
 
 #ifndef MINISIZE
 /* returns the mime_version header.            */
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
-osip_mime_version_t *osip_message_get_mime_version(const osip_message_t * sip)
+osip_mime_version_t *
+osip_message_get_mime_version (const osip_message_t * sip)
 {
-	return sip->mime_version;
+  return sip->mime_version;
 }
 #endif
