@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001-2012 Aymeric MOIZARD amoizard@antisip.com
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -18,8 +18,7 @@
 */
 
 
-#include <stdlib.h>
-#include <stdio.h>
+#include <osipparser2/internal.h>
 
 #include <osipparser2/osip_port.h>
 #include <osipparser2/osip_message.h>
@@ -32,27 +31,26 @@
 /* OUTPUT: osip_message_t *sip | structure to save results. */
 /* returns -1 on error. */
 int
-osip_message_set_proxy_authentication_info(osip_message_t * sip,
-										   const char *hvalue)
+osip_message_set_proxy_authentication_info (osip_message_t * sip, const char *hvalue)
 {
-	osip_proxy_authentication_info_t *proxy_authentication_info;
-	int i;
+  osip_proxy_authentication_info_t *proxy_authentication_info;
+  int i;
 
-	if (hvalue == NULL || hvalue[0] == '\0')
-		return OSIP_SUCCESS;
+  if (hvalue == NULL || hvalue[0] == '\0')
+    return OSIP_SUCCESS;
 
-	i = osip_proxy_authentication_info_init(&(proxy_authentication_info));
-	if (i != 0)
-		return i;
-	i = osip_proxy_authentication_info_parse(proxy_authentication_info, hvalue);
-	if (i != 0) {
-		osip_proxy_authentication_info_free(proxy_authentication_info);
-		return i;
-	}
-	sip->message_property = 2;
+  i = osip_proxy_authentication_info_init (&(proxy_authentication_info));
+  if (i != 0)
+    return i;
+  i = osip_proxy_authentication_info_parse (proxy_authentication_info, hvalue);
+  if (i != 0) {
+    osip_proxy_authentication_info_free (proxy_authentication_info);
+    return i;
+  }
+  sip->message_property = 2;
 
-	osip_list_add(&sip->proxy_authentication_infos, proxy_authentication_info, -1);
-	return OSIP_SUCCESS;
+  osip_list_add (&sip->proxy_authentication_infos, proxy_authentication_info, -1);
+  return OSIP_SUCCESS;
 }
 
 
@@ -61,22 +59,19 @@ osip_message_set_proxy_authentication_info(osip_message_t * sip,
 /* INPUT : osip_message_t *sip | sip message.   */
 /* returns null on error. */
 int
-osip_message_get_proxy_authentication_info(const osip_message_t * sip,
-										   int pos,
-										   osip_proxy_authentication_info_t
-										   ** dest)
+osip_message_get_proxy_authentication_info (const osip_message_t * sip, int pos, osip_proxy_authentication_info_t ** dest)
 {
-	osip_proxy_authentication_info_t *proxy_authentication_info;
+  osip_proxy_authentication_info_t *proxy_authentication_info;
 
-	*dest = NULL;
-	if (osip_list_size(&sip->proxy_authentication_infos) <= pos)
-		return OSIP_UNDEFINED_ERROR;	/* does not exist */
+  *dest = NULL;
+  if (osip_list_size (&sip->proxy_authentication_infos) <= pos)
+    return OSIP_UNDEFINED_ERROR;        /* does not exist */
 
-	proxy_authentication_info = (osip_proxy_authentication_info_t *)
-		osip_list_get(&sip->proxy_authentication_infos, pos);
+  proxy_authentication_info = (osip_proxy_authentication_info_t *)
+    osip_list_get (&sip->proxy_authentication_infos, pos);
 
-	*dest = proxy_authentication_info;
-	return pos;
+  *dest = proxy_authentication_info;
+  return pos;
 }
 
 #endif
